#include <Adafruit_SPIFlash.h>
#include <bluefruit.h>

void startAdv(void)
{  
  // advertising data
  uint8_t adv_data[] = { 0xFF, 0xFF, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09
                       , 0x10, 0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x17, 0x18, 0x19
                       , 0x20, 0x21, 0x22, 0x23, 0x24, 0x25, 0x26, 0x27, 0x28
                       };                          
  Bluefruit.Advertising.addData(BLE_GAP_AD_TYPE_MANUFACTURER_SPECIFIC_DATA, adv_data, sizeof(adv_data)/sizeof(adv_data[0]));

  // scan response data
  uint8_t rsp_data[] = { 0xFF, 0xFF, 0xD2, 0xD3, 0xD4, 0xD5, 0xD6, 0xD7, 0xD8, 0xD9
                       , 0xE0, 0xE1, 0xE2, 0xE3, 0xE4, 0xE5, 0xE6, 0xE7, 0xE8, 0xE9
                       , 0xF0, 0xF1, 0xF2, 0xF3, 0xF4, 0xF5, 0xF6, 0xF7, 0xF8 
                       };
  Bluefruit.ScanResponse.addData(BLE_GAP_AD_TYPE_MANUFACTURER_SPECIFIC_DATA, rsp_data, sizeof(rsp_data)/sizeof(rsp_data[0]));

  Bluefruit.Advertising.setType(BLE_GAP_ADV_TYPE_NONCONNECTABLE_SCANNABLE_UNDIRECTED);  // for XIAO BLE scan response
//  Bluefruit.Advertising.setType(BLE_GAP_ADV_TYPE_CONNECTABLE_SCANNABLE_UNDIRECTED);   // for mobile tool
  Bluefruit.Advertising.restartOnDisconnect(true);
  Bluefruit.Advertising.setIntervalMS(200, 200);    // in unit of ms
  Bluefruit.Advertising.setFastTimeout(1);          // number of seconds in fast mode
  Bluefruit.Advertising.start(1);                   // stop advertising after 1 seconds
}


void setup()
{
  // Shut down unused QSPI flash memory
  Adafruit_FlashTransport_QSPI flashTransport;
  flashTransport.begin();
  flashTransport.runCommand(0xB9);
  flashTransport.end();

  // Enable DC-DC converter
  NRF_POWER->DCDCEN = 1;
  
  Bluefruit.begin();
  Bluefruit.autoConnLed(false); // turn off LED to save power
  Bluefruit.setTxPower(0);      // -40, -20, -16, -12, -8, -4, 0, +2, +3, +4, +5, +6, +7, +8
}

void loop()
{
  startAdv();
  __WFE();
  __WFI();
  delay(10000);  // advertising period = 10s
  Bluefruit.Advertising.clearData();  // refresh advertising data for each cycle
  Bluefruit.ScanResponse.clearData();  // refresh scan response data for each cycle
}
